==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/outputs/GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A server vulnerability assessment.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property recurringScans The recurring scans settings
 * @property storageContainerPath A blob storage container path to hold the scan results (e.g. https://myStorage.blob.core.windows.net/VaScans/).
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult(
    public val id: String,
    public val name: String,
    public val recurringScans: VulnerabilityAssessmentRecurringScansPropertiesResponse? = null,
    public val storageContainerPath: String,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.synapse.outputs.GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult):
            GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult =
            GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult(
                id = javaType.id(),
                name = javaType.name(),
                recurringScans = javaType.recurringScans().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.synapse.kotlin.outputs.VulnerabilityAssessmentRecurringScansPropertiesResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                storageContainerPath = javaType.storageContainerPath(),
                type = javaType.type(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/outputs/GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A server vulnerability assessment.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property recurringScans The recurring scans settings
 * @property storageContainerPath A blob storage container path to hold the scan results (e.g. https://myStorage.blob.core.windows.net/VaScans/).
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult(
    public val id: String,
    public val name: String,
    public val recurringScans: VulnerabilityAssessmentRecurringScansPropertiesResponse? = null,
    public val storageContainerPath: String,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.synapse.outputs.GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult): GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult =
            GetWorkspaceManagedSqlServerVulnerabilityAssessmentResult(
                id = javaType.id(),
                name = javaType.name(),
                recurringScans = javaType.recurringScans().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.synapse.kotlin.outputs.VulnerabilityAssessmentRecurringScansPropertiesResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                storageContainerPath = javaType.storageContainerPath(),
                type = javaType.type(),
            )
    }
}
